package shenikan

// Tips: in python run
//
// import gensim.downloader
// model = gensim.downloader.load("glove-wiki-gigaword-50") # or other models @https://github.com/piskvorky/gensim-data
//
// Then find words related to what you want in model[] and do math on them.
// Then search through model to find nearby vectors using model.most_similar.
// e.g. model.most_similar(model['aunt'] - model['woman'] + model['man'])

// TODO: try generating a penta for each non-syntactic word in toki pona.
// TODO: make more AvB BvC AvBvC penta/icosa sets

_dictionary: {
	glyphs: {
		vowel: "i": ["outer"]
		vowel: "e": ["outer", "slashed"]
		vowel: "a": ["slashed"]
		vowel: "o": ["inner", "slashed"]
		vowel: "u": ["inner"]
		vowel: "y": ["inner", "outer"]

		cluster: "θ": ["left", "top"]
		cluster: "∫": ["left", "middle"]
		cluster: "x": ["left", "bottom"]
		cluster: "n": ["center", "middle"]
		cluster: "p": ["right", "top"]
		cluster: "t": ["right", "middle"]
		cluster: "k": ["right", "bottom"]
		cluster: "θl": ["left", "top", "wide"]
		cluster: "∫l": ["left", "middle", "wide"]
		cluster: "xl": ["left", "bottom", "wide"]
		cluster: "nl": ["center", "middle", "wide"] // use sparingly?
		cluster: "l": ["right", "top", "wide"]      // allophone of pl
		cluster: "tl": ["right", "middle", "wide"]
		cluster: "kl": ["right", "bottom", "wide"]
		cluster: "θr": ["left", "top", "tall"]
		cluster: "∫r": ["left", "middle", "tall"]
		cluster: "xr": ["left", "bottom", "tall"]
		cluster: "nr": ["center", "middle", "tall"] // use sparingly?
		cluster: "r": ["right", "top", "tall"]      // allophone of pr
		cluster: "tr": ["right", "middle", "tall"]
		cluster: "kr": ["right", "bottom", "tall"]
		cluster: "sθ": ["left", "top", "both"]
		cluster: "s∫": ["left", "middle", "both"]
		cluster: "sx": ["left", "bottom", "both"]
		cluster: "sn": ["center", "middle", "both"]
		cluster: "sp": ["right", "top", "both"]
		cluster: "st": ["right", "middle", "both"]
		cluster: "sk": ["right", "bottom", "both"]

		punctuation: "«": ["left"]
		punctuation: ".": []
		punctuation: "»": ["right"]

		numeric: "0": ["circle"]
		numeric: "1": ["dash"]
		numeric: "2": ["vee"]
		numeric: "3": ["hump"]
		numeric: "4": ["dash", "hump"]
		numeric: "5": ["vee", "hump"]
		numeric: ",": ["dot"]
	}

	dialects: {
		// TODO: make these per-consonant-cluster
		"shenkian": {
			"l": "pl"
			"r": "pr"
		}

		"jukashenikan": {
			"x": "ç"
			"p": "j"
		}

		"gazhenigan": {
			"k": "g"
			"∫": "ʒ"
			"s": "z"
			"θ": "ð"
			"t": "d"
		}
	}

	dms: {
		"-at": noun:    "place of"
		"plaxi-": noun: "study of"
	}

	words: {
		"t": {
			noun: "thing": "See t - dmPenta for better meaning."
			verb: "be"
		}
		"tit": {
			noun: "cool"
			from: "t": via: "-t"
		}
	}

	pentas: {
		"n x": {
			name: "Pronouns"
			extremes: {i: "Fully proximal", u: "Fully distal"}

			i: pronoun: "I/me"
			o: {}
		}

		"p ls": {
			name: "Coordinating Conjunctions"
			extremes: {i: "Fully constrasting", u: "Fully non-contrasting"}

			i: conjunction: "but/yet"
			e: conjunction: "exclusive or"
			a: conjunction: "or":      "inclusive or"
			o: conjunction: "implies": "logical implication (not p or q)"
			u: conjunction: "and"
		}

		"sp ns": {
			name: "Group Clusivity"
			extremes: {i: "Fully included", u: "Fully excluded"}

			i: adposition: "among"
			e: adposition: "with"
			a: adposition: "throughout"
			o: adposition: "without"
			u: adposition: "out"
		}

		"r ks": {
			name: "Process"
			extremes: {i: "Beginning", u: "Ending"}

			i: {verb: "start", noun: "start"}
			e: {verb: "resume", noun: "resumption"}
			a: {verb: "continue", noun: "continuation"}
			o: {verb: "stop", noun: "stop"}
			u: {verb: "finish", noun: "finish"}
		}

		"sp t": {
			name: "Truth"
			extremes: {i: "True", u: "False"}

			i: {adjective: "true", noun: "truth"}
			e: {adjective: "valid", noun: "validity"}
			a: {
				adjective: unknown: "Truth value unknown"
				noun: unknown:      "Unknown truth value"
			}
			o: {adjective: "invalid", noun: "invalidity"}
			u: {adjective: "false", noun: "falsehood"}
		}

		"sp shs": {
			name: "Biomes"
			extremes: {i: "Wet Biomes", u: "Dry Biomes"}

			i: noun: ["swamp", "wetlands"]
			e: noun: "rainforest"
			a: noun: "forest"
			o: noun: "grassland"
			u: noun: "desert"
		}

		"sth ps": {
			name: "Generic Plants"
			extremes: {i: "Trees", u: "Grasses"}

			i: noun: "tree"
			e: noun: "vine"
			a: noun: "bush"
			o: noun: "crop"
			u: noun: "grass"
		}

		"k ks": {
			name: "Queries"
			extremes: {i: "Abstract", u: "Concrete"}

			i: noun: "why"
			e: noun: "how"
			a: noun: "when"
			o: noun: "where"
			u: noun: ["what", "which", "who"]
		}
	}

	icosas: {
		"sth sp shs": {
			name: "Plants"
			extremes: {
				ix: "Trees"
				ux: "Grasses"
				xi: "Wet"
				xu: "Dry"
			}

			ix: "Trees"
			ex: "Vines"
			ax: "Bushes"
			ox: "Crops"
			ux: "Grasses"

			xi: "Swamp Plants"
			xe: "Rainforest Plants"
			xa: "Forest Plants"
			xo: "Grassland Plants"
			xu: "Desert Plants"

			ii: noun: "conifer tree"
			ie: noun: "deciduous tree"
			ia: noun: "temperate tree"
			io: noun: "palm tree"
			iu: noun: "desert tree": "Acacia for example"
			ei: noun: "lily"
			ee: noun: "vine"
			ea: noun: "ivy"
			eo: noun: "vine flower": "Rose for example"
			eu: noun: "thornbush"
			ai: noun: "seaweed"
			ae: noun: "fern"
			aa: noun: "bush"
			ao: noun: "shrub"
			au: noun: "cactus"
			oi: noun: "fruit tree"
			oe: noun: "berry bush"
			oa: noun: "legume"
			oo: noun: "cabbage": "Or similar grassland crop"
			ou: noun: "grain"
			ui: noun: "moss"
			ue: noun: "flower": "Specifically ground or \"low\" flowers"
			ua: noun: "grass"
			uo: noun: "corn/maize"
			uu: noun: "lichen"
		}

		"sth sp sshat": {
			name: "Biomes"
		}
	}

	dmPentas: {
		"t -": {
			name: "Articles"
			extremes: {i: "Specific", u: "General"}

			i: syntax: "proper noun indicator"
			e: syntax: "the"
			a: syntax: "a"
			o: syntax: ["any", "some"]
			u: syntax: "all"
		}

		"k -": {
			name: "Listing Prefixes"
			extremes: {i: "Additive", u: "Reductive"}

			i: syntax: "or": "Inclusive or"
			e: syntax: "or": "Exclusive or"
			a: syntax: "and"
			o: syntax: "xnor": "Exclusive nor"
			u: syntax: "nor":  "Neither nor"
		}
	}
}
